@@ -121,6 +121,12 @@ class TestClangDelta(unittest.TestCase):
     def test_remove_nested_function_remove_nested_func1(self):
         self.check_clang_delta('remove-nested-function/remove_nested_func1.cc', '--transformation=remove-nested-function --counter=1')
 
+    def test_remove_try_catch_1(self):
+        self.check_clang_delta('remove-try-catch/try-catch-1.cpp', '--transformation=remove-try-catch --counter=1')
+
+    def test_remove_try_catch_2(self):
+        self.check_clang_delta('remove-try-catch/try-catch-2.cpp', '--transformation=remove-try-catch --counter=2')
+
     def test_remove_unused_field_designated1(self):
         self.check_clang_delta('remove-unused-field/designated1.c', '--transformation=remove-unused-field --counter=1')
 
@@ -278,14 +284,15 @@ class TestClangDelta(unittest.TestCase):
     def test_rename_cxx_method_test3(self):
         self.check_clang_delta('rename-cxx-method/test3.cc', '--transformation=rename-cxx-method --counter=1')
 
-    @unittest.skip(reason='Missing rename for last function')
+    def test_rename_fun_templ(self):
+        self.check_clang_delta('rename-fun/func_templ.cc', '--transformation=rename-fun --counter=1')
+
     def test_rename_fun_multi(self):
         self.check_clang_delta('rename-fun/multi.c', '--transformation=rename-fun --counter=1')
 
     def test_rename_fun_overloaded(self):
         self.check_clang_delta('rename-fun/overloaded.cc', '--transformation=rename-fun --counter=1')
 
-    @unittest.skip(reason='Missing rename for last function')
     def test_rename_fun_test1(self):
         self.check_clang_delta('rename-fun/test1.c', '--transformation=rename-fun --counter=1')
 
