@@ -15,14 +15,13 @@ import importlib.util
 # If the cvise modules cannot be found
 # add the known install location to the path
 if importlib.util.find_spec("cvise") is None:
-    script_path = os.path.dirname(os.path.realpath(__file__))
-    sys.path.append(os.path.join(script_path, "..", "share"))
+    sharedir = "@CMAKE_INSTALL_FULL_DATADIR@"
+    sys.path.append(sharedir)
 
 from cvise import CVise
 from cvise.passes.abstract import AbstractPass
 from cvise.utils.error import CViseError
 from cvise.utils.error import MissingPassGroupsError
-from cvise.utils.info import ExternalPrograms
 from cvise.utils import testing
 from cvise.utils import statistics
 
@@ -32,12 +31,13 @@ class DeltaTimeFormatter(logging.Formatter):
         record.delta = duration.strftime("%H:%M:%S")
         return super().format(record)
 
+script_path = os.path.dirname(os.path.realpath(__file__))
+
 def get_share_dir():
-    script_path = os.path.dirname(os.path.realpath(__file__))
 
     # Test all known locations for the cvise directory
     share_dirs = [
-            os.path.join(script_path, "..", "share", "cvise"),
+            "@CMAKE_INSTALL_FULL_DATADIR@/@cvise_PACKAGE@",
             os.path.join(script_path, "cvise")
             ]
 
@@ -47,36 +47,31 @@ def get_share_dir():
 
     raise CViseError("Cannot find cvise module directory!")
 
-def get_libexec_dir():
-    script_path = os.path.dirname(os.path.realpath(__file__))
-
-    # Test all known locations for the cvise directory
-    libexec_dirs = [
-            os.path.join(script_path, "..", "libexec"),
-            #FIXME: The programs are in sub directories
-            os.path.join(script_path)
-            ]
-
-    for d in libexec_dirs:
-        if os.path.isdir(d):
-            return d
-
-    raise CViseError("Cannot find libexec directory!")
-
 def find_external_programs():
-    programs = ExternalPrograms()
-    libexec_dir = get_libexec_dir()
+    programs = {
+        "clang_delta" : "clang_delta",
+        "clex" : "clex",
+        "topformflat" : "delta" ,
+        "unifdef" : None,
+        }
 
-    for prog_key in ExternalPrograms.programs:
-        prog = programs[prog_key]
+    for prog, local_folder in programs.items():
+        path = None
+        if local_folder:
+            local_folder = os.path.join(script_path, local_folder)
+            path = shutil.which(prog, path=local_folder)
 
-        path = shutil.which(prog)
+            if not path:
+                path = shutil.which(prog, path="@CMAKE_INSTALL_FULL_LIBEXECDIR@/@cvise_PACKAGE@/")
 
-        if path is None:
-            path = shutil.which(prog, path=libexec_dir)
+        if not path:
+            path = shutil.which(prog)
 
         if path is not None:
-            programs[prog_key] = path
+            programs[prog] = path
+
+    # Special case for clang-format
+    programs["clang-format"] = "@CLANG_FORMAT_PATH@"
 
     return programs
 
@@ -112,7 +107,10 @@ EPILOG_TEXT = """
 available shortcuts:
   S - skip execution of the current pass
   D - toggle --print-diff option
-"""
+
+For bug reporting instructions, please use:
+%s
+""" % CVise.Info.PACKAGE_URL
 
 if __name__ == "__main__":
     try:
@@ -134,7 +132,7 @@ if __name__ == "__main__":
     parser.add_argument("--print-diff", action="store_true", default=False, help="Show changes made by transformations, for debugging")
     parser.add_argument("--save-temps", action="store_true", default=False, help="Don't delete /tmp/cvise-xxxxxx directories on termination")
     parser.add_argument("--skip-initial-passes", action="store_true", default=False, help="Skip initial passes (useful if input is already partially reduced)")
-    parser.add_argument("--remove-pass", help="Remove all instances of the specified pass from the schedule")
+    parser.add_argument("--remove-pass", help="Remove all instances of the specified passes from the schedule (comma-separated)")
     parser.add_argument("--timing", action="store_true", default=False, help="Print timestamps about reduction progress")
     parser.add_argument("--timing-since-start", action="store_true", default=False, help="Print timestamps since the start of a reduction")
     parser.add_argument("--timeout", type=int, nargs="?", const=300, help="Interestingness test timeout in seconds")
@@ -147,6 +145,7 @@ if __name__ == "__main__":
     parser.add_argument("--clang-delta-std", type=str, choices=["c++98", "c++11", "c++14", "c++17", "c++20"], help="Specify clang_delta C++ standard, it can rapidly speed up all clang_delta passes")
     parser.add_argument("--not-c", action="store_true", help="Don't run passes that are specific to C and C++, use this mode for reducing other languages")
     parser.add_argument("--list-passes", action="store_true", help="Print all available passes and exit")
+    parser.add_argument("--version", action="version", version='%s (%s)' % (CVise.Info.PACKAGE_STRING, CVise.Info.GIT_VERSION))
     parser.add_argument("interestingness_test", metavar="INTERESTINGNESS_TEST", help="Executable to check interestingness of test cases")
     parser.add_argument("test_cases", metavar="TEST_CASE", nargs="+", help="Test cases")
 
@@ -222,25 +221,30 @@ if __name__ == "__main__":
     reducer.tidy = args.tidy
 
     # Track runtime
-    if args.timing:
-        time_start = time.monotonic()
+    time_start = time.monotonic()
 
     try:
         reducer.reduce(pass_group, skip_initial=args.skip_initial_passes)
     except CViseError as err:
+        time_stop = time.monotonic()
         print(err)
     else:
-        print("pass statistics:")
+        time_stop = time.monotonic()
+        print("===< PASS statistics >===")
+        print("  %-54s %8s %8s %8s %8s %15s" % ("pass name", "time (s)", "time (%)", "worked",
+            "failed", "total executed"))
 
-        for item in pass_statistic.sorted_results:
-            print("method {pass} worked {worked} times and failed {failed} times".format(**item))
+        for pass_name, pass_data in pass_statistic.sorted_results:
+            print("  %-54s %8.2f %8.2f %8d %8d %15d" % (pass_name, pass_data.total_seconds,
+                100.0 * pass_data.total_seconds / (time_stop - time_start),
+                pass_data.worked, pass_data.failed, pass_data.totally_executed))
+        print()
 
         for test_case in test_manager.sorted_test_cases:
             with open(test_case) as test_case_file:
                 print(test_case_file.read())
 
     if args.timing:
-        time_stop = time.monotonic()
         print("Runtime: {} seconds".format(round((time_stop - time_start))))
 
     logging.shutdown()
