@@ -20,7 +20,6 @@ class CVise:
         PACKAGE_VERSION = "@cvise_PACKAGE_VERSION@"
 
         VERSION = "@cvise_VERSION@"
-
         GIT_VERSION = "@GIT_HASH@"
 
     pass_name_mapping = {
@@ -61,6 +60,7 @@ class CVise:
     def parse_pass_group_dict(cls, pass_group_dict, pass_options, external_programs, remove_pass,
             clang_delta_std, not_c):
         pass_group = {}
+        removed_passes = set(remove_pass.split(",")) if remove_pass else set()
 
         def parse_options(options):
             valid_options = set()
@@ -96,7 +96,7 @@ class CVise:
                     raise CViseError("Unkown pass {}".format(pass_dict["pass"]))
 
                 pass_instance = pass_class(pass_dict.get("arg"), external_programs)
-                if str(pass_instance) == remove_pass:
+                if str(pass_instance) in removed_passes:
                     continue
 
                 if not_c and "c" in pass_dict and pass_dict["c"]:
@@ -134,27 +134,28 @@ class CVise:
     @staticmethod
     def _check_prerequisites(pass_group):
         passes = set()
-        missing = set()
 
         for category in pass_group:
             for p in pass_group[category]:
                 if not p.check_prerequisites():
                     logging.error("Prereqs not found for pass {}".format(p))
-                    missing.add(str(p))
-
-        if missing:
-            raise PrerequisitesNotFoundError(missing)
 
     def _run_additional_passes(self, passes):
         for p in passes:
-            self.test_manager.run_pass(p)
+            if not p.check_prerequisites():
+                logging.error("Skipping {}".format(p))
+            else:
+                self.test_manager.run_pass(p)
 
     def _run_main_passes(self, passes):
         while True:
             total_file_size = self.test_manager.total_file_size
 
             for p in passes:
-                self.test_manager.run_pass(p)
+                if not p.check_prerequisites():
+                    logging.error("Skipping pass {}".format(p))
+                else:
+                    self.test_manager.run_pass(p)
 
             logging.info("Termination check: size was {}; now {}".format(total_file_size, self.test_manager.total_file_size))
 
