@@ -52,6 +52,7 @@ class TestEnvironment:
         self.transform = transform
         self.pid_queue = pid_queue
         self.copy_files(test_case, additional_files)
+        self.pwd = os.getcwd()
 
     def copy_files(self, test_case, additional_files):
         if test_case is not None:
@@ -108,13 +109,16 @@ class TestEnvironment:
             pass
         except Exception as e:
             print('Should not happen: ' + str(e))
+        finally:
+            return self
 
     def run_test(self):
-        cmd = [self.test_script]
-        if self.test_case is not None:
-            cmd.append(self.test_case_path)
-        cmd.extend(self.additional_files_paths)
-        _, _, returncode = ProcessEventNotifier(self.pid_queue).run_process(cmd)
+        try:
+            os.chdir(self.folder)
+            cmd = [self.test_script]
+            _, _, returncode = ProcessEventNotifier(self.pid_queue).run_process(cmd)
+        finally:
+            os.chdir(self.pwd)
         return returncode
 
 class TestManager:
@@ -151,7 +155,7 @@ class TestManager:
         self.root = None
 
         if not self.is_valid_test(self.test_script):
-            raise InvalidInterestingnessTestError(test)
+            raise InvalidInterestingnessTestError(self.test_script)
 
     def create_root(self):
         self.root = tempfile.mkdtemp(prefix=self.TEMP_PREFIX)
@@ -182,7 +186,7 @@ class TestManager:
 
     def backup_test_cases(self):
         for f in self.test_cases:
-            orig_file = "{}.orig".format(os.path.splitext(f)[0])
+            orig_file = "{}.orig".format(f)
 
             if not os.path.exists(orig_file):
                 # Copy file and preserve attributes
@@ -263,7 +267,7 @@ class TestManager:
         if returncode == 0:
             logging.debug("sanity check successful")
         else:
-            raise InsaneTestCaseError(self.test_cases, [])
+            raise InsaneTestCaseError(self.test_cases, self.test_script)
 
     def release_folder(self, future):
         name = self.temporary_folders.pop(future)
@@ -332,7 +336,7 @@ class TestManager:
                             quit_loop = True
                             new_futures.add(future)
                 else:
-                    self.pass_statistic.update(self.current_pass, success=False)
+                    self.pass_statistic.add_failure(self.current_pass)
                     if test_env.result == PassResult.OK:
                         assert test_env.exitcode
                         if (self.also_interesting is not None and
@@ -399,6 +403,7 @@ class TestManager:
                 future = pool.schedule(test_env.run, timeout=self.timeout)
                 self.temporary_folders[future] = folder
                 self.futures.append(future)
+                self.pass_statistic.add_executed(self.current_pass)
                 order += 1
                 state = self.current_pass.advance(self.current_test_case, self.state)
                 # we are at the end of enumeration
@@ -423,6 +428,7 @@ class TestManager:
         if self.total_file_size == 0:
             raise ZeroSizeError(self.test_cases)
 
+        self.pass_statistic.start(self.current_pass)
         if not self.skip_key_off:
             logger = readkey.KeyLogger()
 
@@ -478,6 +484,7 @@ class TestManager:
                     self.cache[pass_key][test_case_before_pass] = tmp_file.read()
 
         self.remove_root()
+        self.pass_statistic.stop(self.current_pass)
 
     def process_result(self, test_env):
         logging.debug("Process result")
@@ -489,7 +496,7 @@ class TestManager:
         shutil.copy(test_env.test_case_path, self.current_test_case)
 
         self.state = self.current_pass.advance_on_success(test_env.test_case_path, test_env.state)
-        self.pass_statistic.update(self.current_pass, success=True)
+        self.pass_statistic.add_success(self.current_pass)
 
         pct = 100 - (self.total_file_size * 100.0 / self.orig_total_file_size)
         logging.info("({}%, {} bytes)".format(round(pct, 1), self.total_file_size))
